@@ -1,5 +1,6 @@
 from isc_common.auth.managers.user_manager import UserManager
 from isc_common.auth.models.user import User
+from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -7,6 +8,7 @@ from isc_common.http.response import JsonResponse
 
 @JsonResponseWithException(printing=False)
 def User_Fetch(request):
+    _request = DSRequest(request)
     return JsonResponse(
         DSResponse(
             request=request,
