@@ -46,12 +46,13 @@ class DSRequest(RPCRequest):
     dataPageSize = 75
     drawAheadRatio = 1.2
     enabledAll = None
-    enddate = None
     endRow = None
+    enddate = None
+    httpHeaders = None
     json = None
     startRow = None
     tag = None
-    httpHeaders = None
+    transaction = None
     visibleMode = 'none'
 
     _user = None
@@ -73,7 +74,7 @@ class DSRequest(RPCRequest):
                                 self._user = User.objects.get(id=data.httpHeaders.USER_ID)
                                 return self._user
 
-                raise Exception('user not enable type')
+                # raise Exception('user not enable type')
         return self._user
 
     @property
@@ -98,15 +99,18 @@ class DSRequest(RPCRequest):
 
     def set_user_data(self, user):
         from isc_common.auth.models.user import User
-        if isinstance(user, int):
-            self._user = User.objects.get(id=user)
+        from isc_common.number import ToInt
+
+        _user = ToInt(user)
+        if isinstance(_user, int):
+            self._user = User.objects.get(id=_user)
         elif isinstance(user, str):
             self._user = User.objects.get(username=user)
         else:
             raise Exception('user not enable type')
 
     def __init__(self, request):
-
+        from django.http import QueryDict
         if request is not None and request.body != b'':
             self.json = BytesToJson(request.body)
             if isinstance(self.json, dict) and len(self.json) > 0:
@@ -143,6 +147,24 @@ class DSRequest(RPCRequest):
                         if httpHeaders is not None:
                             self.set_user_data(user=httpHeaders.get('USER_ID'))
 
+        elif isinstance(request.GET, QueryDict):
+            get_dict = dict(request.GET)
+            ws_channel = get_dict.get('ws_channel')
+            if isinstance(ws_channel, list) and len(ws_channel) > 0:
+                self.ws_channel = ws_channel[0]
+
+            port = get_dict.get('port')
+            if isinstance(port, list) and len(port) > 0:
+                self.ws_port = port[0]
+
+            host = get_dict.get('host')
+            if isinstance(host, list) and len(host) > 0:
+                self.host = host[0]
+
+            user_id = get_dict.get('user_id')
+            if isinstance(user_id, list) and len(user_id) > 0:
+                self.set_user_data(user=user_id[0])
+
         RPCRequest.__init__(self, self.json)
 
     def delete_underscore_element(self, data):
